@@ -263,7 +263,10 @@ test_that("ssd_hp cis with non-convergence", {
   expect_identical(attr(fit, "min_pmix"), 0.3)
   hp30 <- ssd_hp(fit, conc = 1, ci = TRUE, nboot = 100, min_pboot = 0.96)
   expect_s3_class(hp30, "tbl")
-  expect_snapshot_data(hp30, "hp_30")
+  testthat::skip_on_os("windows")
+  testthat::skip_on_os("linux")
+  testthat::skip_on_os("solaris")
+  expect_snapshot_boot_data(hp30, "hp_30")
 })
 
 test_that("ssd_hp cis with error", {
@@ -274,10 +277,15 @@ test_that("ssd_hp cis with error", {
   expect_identical(attr(fit, "min_pmix"), 0.1)
   expect_warning(hp_err <- ssd_hp(fit, conc = 1, ci = TRUE, nboot = 100))
   expect_s3_class(hp_err, "tbl")
-  expect_snapshot_data(hp_err, "hp_err_na")
+  testthat::skip_on_os("windows")
+  testthat::skip_on_os("linux")
+  testthat::skip_on_os("solaris")
+  expect_snapshot_boot_data(hp_err, "hp_err_na")
   hp_err <- ssd_hp(fit, conc = 1, ci = TRUE, nboot = 100, min_pboot = 0.92)
   expect_s3_class(hp_err, "tbl")
-  expect_snapshot_data(hp_err, "hp_err")
+  testthat::skip_on_ci()
+  testthat::skip_on_cran()
+  expect_snapshot_boot_data(hp_err, "hp_err")
 })
 
 test_that("ssd_hp cis with error and multiple dists", {
@@ -289,11 +297,17 @@ test_that("ssd_hp cis with error and multiple dists", {
   set.seed(99)
   expect_warning(hp_err_two <- ssd_hp(fit, conc = 1, ci = TRUE, nboot = 100, average = FALSE,
                                       delta = 100))
-  expect_snapshot_data(hp_err_two, "hp_err_two")
+  testthat::skip_on_os("windows")
+  testthat::skip_on_os("linux")
+  testthat::skip_on_os("solaris")  
+  expect_snapshot_boot_data(hp_err_two, "hp_err_two")
   set.seed(99)
   expect_warning(hp_err_avg <- ssd_hp(fit, conc = 1,  ci = TRUE, nboot = 100,
                                       delta = 100))
-  expect_snapshot_data(hp_err_avg, "hp_err_avg")
+  testthat::skip_on_os("windows")
+  testthat::skip_on_os("linux")
+  testthat::skip_on_os("solaris")
+  expect_snapshot_boot_data(hp_err_avg, "hp_err_avg")
 })
 
 test_that("ssd_hp with 1 bootstrap", {
@@ -309,8 +323,12 @@ test_that("ssd_hp comparable parametric and non-parametric big sample size", {
   fit <- ssd_fit_dists(data, dists = "lnorm")
   set.seed(10)
   hp_para <- ssd_hp(fit, 1, ci = TRUE, nboot = 10)
-  expect_snapshot_data(hp_para, "hp_para")
+  testthat::skip_on_ci()
+  testthat::skip_on_cran()
+  expect_snapshot_boot_data(hp_para, "hp_para")
   set.seed(10)
   hp_nonpara <- ssd_hp(fit, 1, ci = TRUE, nboot = 10, parametric = FALSE)
-  expect_snapshot_data(hp_nonpara, "hp_nonpara")
+  testthat::skip_on_ci()
+  testthat::skip_on_cran()
+  expect_snapshot_boot_data(hp_nonpara, "hp_nonpara")
 })
